from litestar import Litestar, Request, get
from litestar.logging import LoggingConfig
from litestar.testing import TestClient

logging_config = LoggingConfig(
    loggers={
        "app": {
            "level": "DEBUG",
            "handlers": ["queue_listener"],
            "propagate": False,
        }
    }
)


@get("/")
def hello_world(request: Request) -> dict[str, str]:
    """Handler function that returns a greeting dictionary."""
    request.logger.info("No results in response")
    request.logger.debug("doing things...")
    return {"hello": "world"}


app = Litestar(
    route_handlers=[hello_world],
    logging_config=logging_config,
    debug=True,
)

if __name__ == "__main__":
    with TestClient(app=app) as client:
        for _ in range(100_000):
            response = client.get("/")



import io

try:
    import coloredlogs

    has_libs = True
except ImportError:
    has_libs = False

import pytest

import picologging as logging


@pytest.mark.skipif(not has_libs, reason="Missing libraries")
def test_coloredlogs_logger():
    # Setup colored logger
    stream = io.StringIO()

    logger = logging.getLogger()
    logger.addHandler(logging.StreamHandler(stream))
    coloredlogs.install(logger=logger, level="INFO")

    logger.info("Info message")
    logger.warning("Warning message")
    logger.error("Error message")
    logger.critical("Critical message")

    log = stream.getvalue()
    assert "Info message" in log
    assert "Warning message" in log
    assert "Error message" in log
    assert "Critical message" in log



import picologging
from picologging import LogRecord


def log():
    for _ in range(100_000):
        record = LogRecord(
            "hello", picologging.WARNING, __file__, 123, "bork %s", None, None
        )
        assert record.message is None
        assert record.getMessage() == "bork %s"
        assert record.message == "bork %s"
        assert "name" in record.__dict__


if __name__ == "__main__":
    log()



import picologging


def test():
    perc = picologging.PercentStyle("%(msg)s %(levelno)d %(name)s")
    record = picologging.LogRecord(
        "test", picologging.INFO, __file__, 1, "hello", (), None, None, None
    )

    assert perc.format(record) == "hello 20 test"

    try:
        perc.format(None)
    except:
        pass
    try:
        perc.format("")
    except:
        pass

    try:
        perc.format({})
    except:
        pass


if __name__ == "__main__":
    for _ in range(1000):
        test()
